import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
 * Demonstrates how to perform a search by specifying a set of
 * attributes to be matched. Returns selected attributes of objects
 * that contain those matching attributes.
 *
 * usage: java Search
 */
class Search {
    public static void printSearchEnumeration(NamingEnumeration enum) {
	try {
	    while (enum.hasMore()) {
		SearchResult sr = (SearchResult)enum.next();
		System.out.println(">>>" + sr.getName());
		GetattrsAll.printAttrs(sr.getAttributes());
	    }
	} catch (NamingException e) {
	    e.printStackTrace();
	}
    }

    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	try {
	    // Create initial context
	    DirContext ctx = new InitialDirContext(env);

	    // Specify the ids of the attributes to return
	    String[] attrIDs = {"sn", "telephonenumber", "golfhandicap", "mail"};

	    // Specify the attributes to match
	    // Ask for objects with attribute shoesize == 14 and which have
	    // the "mail" attribute.
	    Attributes matchAttrs = new BasicAttributes(true); // ignore case
	    matchAttrs.put(new BasicAttribute("shoesize", "14"));
	    matchAttrs.put(new BasicAttribute("mail"));

	    // Search for objects with those matching attributes
	    NamingEnumeration answer = 
		ctx.search("ou=People", matchAttrs, attrIDs);

	    // Print the answer
	    printSearchEnumeration(answer);
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
